==> 0.0.2.tar.gz: lib/esp_bluetooth_provisioning.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

import 'enums.dart';

class EspBleProvisioning {
  static const MethodChannel _channel = const MethodChannel('esp_ble_provisioning');
  int _stateScannerCount = 0;
  Map<String, StreamController<BluetoothState>> _stateStreamPool = {};


  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<Map> scanBluetoothDevice() async {
    try {
      var result = await _channel.invokeMethod('startProvisioningFlow');
      print("************Result from Bluetooth devices");
      print(result);
      return result;
    } on PlatformException catch (e) {
      print("Failed to scan device: '${e.message}'.");
    }
  }

  Future<bool> connectToBluetoothDevice(String name) async {
    try {
      print("************Connecting to Bluetooth devices");
      var result = await _channel.invokeMethod('ConnectToBlueTooth',  {"name": name});
      print("************Connection from Bluetooth devices");
      print(result);
      return result;
    } on PlatformException catch (e) {
      print("Failed to connect device: '${e.message}'.");
    }
  }

  Future<String> startProvisioning(String ssid, String password) async {
    try {
      print("************Connecting to Bluetooth devices");
      var value = await _channel.invokeMethod('StartProvisioning', {"ssid": ssid, "password": password});
        print("************Device Provisioned");
        print(value);
        return value;

    } on PlatformException catch (e) {
      print("Failed to provision device: '${e.message}'.");
    }
  }

  /// Stream which splits the bluetooth adapter state
  // Stream<BluetoothState> getBluetoothStateStream() {
  //   String method = "bluetoothStateListener#${++_stateScannerCount}";
  //   _stateStreamPool[method] =
  //       _getNewBluetoothStateStreamController<BluetoothState>(method);
  //   _channel.invokeMethod(method);
  //   return _stateStreamPool[method].stream;
  // }
  //
  // /// Retrives the permission state of the scanner
  // Future<BluetoothPermissionState> getPermissionState() async {
  //   return _getBluetoothPermissionStateFromKey(
  //       await _channel.invokeMethod<String>("permissionState"));
  // }

  /// Asks for location permission from the platfrom
  void requestPermission() {
    print("**********REQUESTING PERMISSION");
    _channel.invokeMethod<String>("requestPermission");
  }
}

==> 0.0.5.tar.gz: lib/esp_bluetooth_provisioning.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

import 'enums.dart';

class EspBleProvisioning {
  static const MethodChannel _channel = const MethodChannel('esp_ble_provisioning');
  int _stateScannerCount = 0;
  Map<String, StreamController<BluetoothState>> _stateStreamPool = {};


  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<Map> scanBluetoothDevice() async {
    try {
      var result = await _channel.invokeMethod('startProvisioningFlow');
      print("************Result from Bluetooth devices");
      print(result);
      return result;
    } on PlatformException catch (e) {
      print("Failed to scan device: '${e.message}'.");
    }
  }

  Future<bool> connectToBluetoothDevice(String name) async {
    try {
      print("************Connecting to Bluetooth devices");
      await _channel.invokeMethod('ConnectToBlueTooth',  {"name": name}).then((value) {
        print("************Connection from Bluetooth devices");
        print(value);
        return value;
      });

    } on PlatformException catch (e) {
      print("Failed to connect device: '${e.message}'.");
    }
  }

  Future<bool> checkProof() async {
    try {
      print("************Checking proof");
      return await _channel.invokeMethod('checkProof').then((value){
        print("************Proof of possession");
        print(value);
        return true;
      });


    } on PlatformException catch (e) {
      print("Failed to proof device: '${e.message}'.");
    }
  }

  Future<bool> startProvisioning(String ssid, String password) async {
    try {
      print("************Trying to provision device");
      return await _channel.invokeMethod('StartProvisioning', {"ssid": ssid, "password": password});
        // print(value);
        // return true;

    } on PlatformException catch (e) {
      print("Failed to provision device: '${e.message}'.");
    }
  }

  Future<String> checkProvisioningStatus() async {
    try {
      print("************checking status");
      return await _channel.invokeMethod('checkProvisioningStatus',);
      // print(value);
      // return value;

    } on PlatformException catch (e) {
      print("Failed to check provision status: '${e.message}'.");
    }
  }

  /// Stream which splits the bluetooth adapter state
  // Stream<BluetoothState> getBluetoothStateStream() {
  //   String method = "bluetoothStateListener#${++_stateScannerCount}";
  //   _stateStreamPool[method] =
  //       _getNewBluetoothStateStreamController<BluetoothState>(method);
  //   _channel.invokeMethod(method);
  //   return _stateStreamPool[method].stream;
  // }
  //
  // /// Retrives the permission state of the scanner
  // Future<BluetoothPermissionState> getPermissionState() async {
  //   return _getBluetoothPermissionStateFromKey(
  //       await _channel.invokeMethod<String>("permissionState"));
  // }

  /// Asks for location permission from the platfrom
  void requestPermission() {
    print("**********REQUESTING PERMISSION");
    _channel.invokeMethod<String>("requestPermission");
  }
}
